#
# spec file for package python-pendulum
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pendulum
Version:        2.1.2
Release:        3.6
Summary:        Python datetimes made easy
License:        MIT
Group:          Development/Languages/Python
URL:            https://pendulum.eustace.io
# https://github.com/sdispater/pendulum/issues/453
Source:         https://github.com/sdispater/pendulum/archive/%{version}.tar.gz#/pendulum-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil >= 2.6}
BuildRequires:  %{python_module pytz >= 2020.1}
BuildRequires:  %{python_module pytzdata >= 2020.1}
BuildRequires:  %{python_module typing}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-python-dateutil >= 2.6
Requires:       python-pytz >= 2020.1
Requires:       python-pytzdata >= 2020.1
Requires:       python-typing
%python_subpackages

%description
Python datetimes made easy

%prep
%setup -q -n pendulum-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%{python_expand # remove source files
find %{buildroot}%{$python_sitearch} -name '*.c' -delete
%fdupes %{buildroot}%{$python_sitearch}
}

%check
# https://github.com/sdispater/pendulum/issues/644
donttest="(test_timezone and test_dst) or (test_behavior and test_proper_dst)"
%pytest_arch -k "not ($donttest)"

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitearch}/pendulum
%{python_sitearch}/pendulum-%{version}*-info

%changelog
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Aug 25 2022 Ben Greiner <code@bnavigator.de>
- Skip failing DST tests for Amsterdam during Nazi occupation
  * gh#sdispater/pendulum#644
* Tue Oct 27 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 2.1.2
  * Added support for build scripts without the setup.py file
    generation in the editable builder (#2718).
  * Fixed an error occurring when using older lock files (#2717).
- Changelog for version 2.1.1
  * Fixed errors where invalid timezones were matched in
    from_format() (#374).
  * Fixed errors when subtracting negative timedeltas (#419).
  * Fixed errors in total units computation for durations
    with years and months (#482).
  * Fixed an error where the fold attribute was overridden
    when using replace() (#414).
  * Fixed an error where now() was not returning the
    correct result on DST transitions (#483).
  * Fixed inconsistent typing annotation for the parse()
    function (#452).
  * Added the pl locale (#459).
- Build the extensions
- Kill dephell dependency
- Disable python2 package (no python2-poetry-core in Leaps
  sr#842815)
* Mon Apr 27 2020 Tomáš Chvátal <tchvatal@suse.com>
- Depend on python-dateutil not just dateutil to solve on Leap
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Tue Mar 24 2020 pgajdos@suse.com
- version update to 2.1.0
  Added
    Added better typing and PEP-561 compliance (#320).
    Added the is_anniversary() method as an alias of is_birthday() (#298).
  Changed
    Dropped support for Python 3.4.
    is_utc() will now return True for any datetime with an offset of 0, similar to the behavior in the 1.* versions (#295)
    Duration.in_words() will now return 0 milliseconds for empty durations.
  Fixed
    Fixed various issues with timezone transitions for some edge cases (#321, (#350)).
    Fixed out of bound detection for nth_of("month") (#357).
    Fixed an error where extra text was accepted in from_format() (#372).
    Fixed a recursion error when adding time to a DateTime with a fixed timezone (#431).
    Fixed errors where Period instances were not properly compared to other classes, especially timedelta instances (#427).
    Fixed deprecation warnings due to internal regexps (#427).
    Fixed an error where the test() helper would not unset the test instance when an exception was raised (#445).
    Fixed an error where the week_of_month attribute was not returning the correct value (#446).
    Fixed an error in the way the Z ISO-8601 UTC designator was not parsed as UTC (#448).
* Tue Mar  3 2020 Axel Braun <axel.braun@gmx.de>
- added pytzdata as dependency
* Mon Aug 26 2019 Axel Braun <axel.braun@gmx.de>
- version 2.0.5
  clean-up of spec file
  license from PGK-INFO added
* Wed Apr  3 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2.0.4
